Process Analysis
This module contains techniques related to the analysis of event data or other process artifacts.
Modules
- case_
centric - Case-centric Process Analysis
- object_
centric - Object-centric Process Analysis
Process Analysis
This module contains techniques related to the analysis of event data or other process artifacts.