Module oc_declare

Module oc_declare 

Discovering OC-DECLARE Models from Object-Centric Event Data

Structs

OCDeclareDiscoveryOptions
Options for the automatic discovery of OC-DECLARE constraints

Enums

O2OMode
O2O Mode for OC-DECLARE Discovery
OCDeclareReductionMode
Mode for reducing OC-DECLARE constraints

Functions

combine_constraints
Combine constraints by trying to merge their labels
discover_behavior_constraints
Discover behavioral OC-DECLARE constraints from the given OCEL
get_oi_labels
Get possible object involvement labels for given activity pair and object involvements
reduce_oc_arcs
Reduce OC-DECLARE arcs based on lossless/lossy transitive reduction considering paths of arbitrary length. Uses sequential processing to prevent mutual elimination in cycles.
refine_oc_arcs
Refine OC-DECLARE arcs by trying to find stricter object involvement labels