Struct process_mining::event_log::stream_xes::XESOuterLogData
source · pub struct XESOuterLogData {
pub extensions: Vec<EventLogExtension>,
pub classifiers: Vec<EventLogClassifier>,
pub log_attributes: Attributes,
pub global_trace_attrs: Attributes,
pub global_event_attrs: Attributes,
}Expand description
(Global) log data parsed during streaming
According to the state machine flow in XES standard (https://xes-standard.org/_media/xes/xesstandarddefinition-2.0.pdf#page=11) those must occur before the first trace
Thus, for XES-compliant logs it is guaranteed that this data is already complete once the first trace is parsed.
Fields
extensions: Vec<EventLogExtension>XES Extensions of event log
classifiers: Vec<EventLogClassifier>Event Classifiers of event log
log_attributes: AttributesLog-level attributes of event log
global_trace_attrs: AttributesGlobal trace attributes of event log
global_event_attrs: AttributesGlobal event attributes of event log