PartialOrderTrace

Struct PartialOrderTrace 

pub struct PartialOrderTrace {
    pub attributes: Attributes,
    pub event_map: HashMap<EventHash, Event>,
    pub partial_relations: HashSet<(EventHash, EventHash)>,
}
A partial order trace of Events. Contains all events of a trace and their particular partial relations.

Fields

attributes: Attributes

Trace-level attributes

event_map: HashMap<EventHash, Event>

A mapping from an Event’s hash value EventHash to the Event itself.

partial_relations: HashSet<(EventHash, EventHash)>

The partial relations between the Events contained in the PartialOrderTrace.

Implementations

Source

impl PartialOrderTrace

pub fn new() -> Self

Create new PartialOrderTrace with no events and no partial relations.

pub fn to_json(self) -> String

Serialize to JSON string.

pub fn get_start_events(&self) -> HashSet<&Event>

Returns all the start events of the PartialOrderTrace, i.e., the events having no preceding event.

pub fn get_end_events(&self) -> HashSet<&Event>

Returns all the end events of the PartialOrderTrace, i.e., the events having no succeeding event.

pub fn add_event(&mut self, event: &Event)

Adds an Event to the PartialOrderTrace.

pub fn remove_event(&mut self, event: &Event)

Removes an Event from the PartialOrderTrace including all partial relations containing the Event itself.

pub fn add_partial_relation(&mut self, from: &Event, to: &Event)

Adds a partial relation by adding two EventHash values.

pub fn remove_partial_relation(&mut self, from: &Event, to: &Event)

Removes a partial relation identified by two EventHash values.

pub fn get_ingoing_events(&self, event: &Event) -> Vec<&Event>

Returns all events preceding an Event.

pub fn get_outgoing_events(&self, event: &Event) -> Vec<&Event>

Returns all events succeeding an Event.

pub fn to_graph(&self, classifier: &EventLogClassifier) -> Graph<String, &str>

Creates a Graph from the PartialOrderTrace.

pub fn is_isomorphic( &self, other: &PartialOrderTrace, classifier: &EventLogClassifier, other_classifier: &EventLogClassifier, ) -> bool

By creating a Graph for each PartialOrderTrace and for two given EventLogClassifier used for classification in each PartialOrderTrace, the partial order traces are compared for equality by checking whether their graphs are isomorphic.

pub fn export_png<P: AsRef<Path>>( &self, classifier: &EventLogClassifier, path: P, ) -> Result<(), Error>

Export directly-follows graph as a PNG image

The PNG file is written to the specified filepath

Note: This is an export method for visualizing the directly-follows graph.

Only available with the graphviz-export feature.

pub fn export_svg<P: AsRef<Path>>( &self, classifier: &EventLogClassifier, path: P, ) -> Result<(), Error>

Export directly-follows graph as an SVG image.

The SVG file is written to the specified filepath.

Note: This is an export method for visualizing the directly-follows graph.

Only available with the graphviz-export feature.